package handlers

import (
	"strconv"

	"github.com/gofiber/fiber/v2"
)

// GenerateBarcode godoc
//
//	@Summary		Generate barcodes
//	@Description	Generate barcodes based on the provided data
//	@Tags			barcodes
//	@Param			type	path	string	true	"Barcode type"		Enums(ean13, code128)
//	@Param			content	path	string	true	"Barcode content"	MinLength(1)
//	@Param			width	query	int		false	"Barcode width"		Minimum(1)	Maximum(10000) default(1000)
//	@Param			height	query	int		false	"Barcode height"	Minimum(1)	Maximum(10000) default(1000)
//	@Produce		image/png
//	@Router			/v1/barcodes/{type}/{content} [get]
func (h *DefaultHandler) GenerateBarcode(c *fiber.Ctx) error {

	// Get the type and content from the URL
	barcodeType := c.Params("type")
	barcodeContent := c.Params("content")

	// Get the width and height from the query parameters
	widthStr := c.Query("width", "1000")
	heightStr := c.Query("height", "1000")

	// Convert width and height to integers
	width, err := strconv.Atoi(widthStr)
	if err != nil {
		return c.Status(fiber.StatusBadRequest).JSON(fiber.Map{
			"error": "Invalid width parameter",
		})
	}

	height, err := strconv.Atoi(heightStr)
	if err != nil {
		return c.Status(fiber.StatusBadRequest).JSON(fiber.Map{
			"error": "Invalid height parameter",
		})
	}

	// Generate the barcode
	barcode, err := h.BarcodeService.GenerateBarcode(barcodeType, barcodeContent, width, height)
	if err != nil {
		return c.Status(fiber.StatusInternalServerError).JSON(fiber.Map{
			"error": err.Error(),
		})
	}

	c.Set(fiber.HeaderContentType, "image/png")
	return c.Send(barcode.Bytes())
}
